/*
 * ttd, a time table displayer 
 * Copyright (C) 2004 Olivier Mehani <shtrom@ssji.net>
 * 
 * $Id: ttd-gtk.c,v 1.5 2004/03/07 19:55:12 shtrom Exp $
 * gtk functions
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include "ouvej.h"
#include "ttd.h"

#define BUFSIZE	32

static gint end(GtkWidget *w, gpointer data)
{
	exit(0);
}

GtkWidget *ttd_gtk_mainwin(int n, lesson_t *ll)
{	
	GtkWidget *win;
	GtkWidget *layout;
	GtkWidget *hbox;
	GtkWidget *ebox;
	GtkWidget *lesson;
	GtkRcStyle *rc_style[sizeof(lesson_type_t)];
	GdkColor colors[sizeof(lesson_type_t)];
	week_day_t last_day=D_ERROR;
	int i, len;
	char str[BUFSIZE];

#define INIT_COLOR(color,lesson_type) do { \
		gdk_color_parse(color,&colors[lesson_type]); \
		rc_style[lesson_type] = gtk_rc_style_new(); \
		rc_style[lesson_type]->bg[GTK_STATE_NORMAL] = colors[lesson_type]; \
		rc_style[lesson_type]->color_flags[GTK_STATE_NORMAL] |= GTK_RC_BG; \
	} while(0);
	
	INIT_COLOR("#00ffff",L_C);
	INIT_COLOR("#00ff00",L_D);
	INIT_COLOR("#ffff00",L_T);
	
	win=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(win),"ttd");
	gtk_signal_connect(GTK_OBJECT(win), "delete_event", GTK_SIGNAL_FUNC(end),win);
	gtk_window_set_default_size(GTK_WINDOW(win),220,700);
	hbox=gtk_hbox_new(FALSE,0);
	gtk_container_add(GTK_CONTAINER(win), hbox);
	gtk_widget_show(hbox);

	for (i=0;i<n;i++) {
		if(last_day!=ll[i].day || layout==NULL) {
			layout=gtk_layout_new(FALSE,0);
			gtk_layout_set_size(GTK_LAYOUT(layout), 45,700);
			gtk_container_add(GTK_CONTAINER(hbox), layout);
			gtk_widget_show(layout);
			last_day=ll[i].day;
		}

		snprintf(str,BUFSIZE,"%s\n%s",ll[i].name,ll[i].place);
		if(ll[i].type==L_D || ll[i].type==L_T) {
			len=strlen(str);
			snprintf(&str[len],BUFSIZE-len,"\n\ngr %d",ll[i].group);
		}

		ebox=gtk_event_box_new();
#define H2P(t)	(t.hour*60+t.minutes-8*60)
#define L2S(ll) (H2P(ll.end)-H2P(ll.beginning))
		gtk_widget_modify_style (ebox, rc_style[ll[i].type]);
		gtk_widget_show(ebox);
		
		lesson=gtk_label_new(str);

		if(ll[i].week_seq!=W_BOTH) {
			gtk_widget_set_usize(lesson,20,L2S(ll[i]));
		} else {
			gtk_widget_set_usize(lesson,40,L2S(ll[i]));
		}

		if(ll[i].week_seq==W_B) {
			gtk_layout_put(GTK_LAYOUT(layout), ebox,22,H2P(ll[i].beginning));
		} else {
			gtk_layout_put(GTK_LAYOUT(layout), ebox,0,H2P(ll[i].beginning));
		}

		gtk_container_add(GTK_CONTAINER(ebox), lesson);
		gtk_widget_show(lesson);
	}
	
	gtk_widget_show(win);
	
	return win;
}
